@@ -21,11 +21,15 @@
 #define DKIMMANAGERKEYDIALOG_H
 
 #include <QDialog>
-#include "messageviewer_private_export.h"
+#include "messageviewer_export.h"
 
 namespace MessageViewer {
 class DKIMManagerKeyWidget;
-class MESSAGEVIEWER_TESTS_EXPORT DKIMManagerKeyDialog : public QDialog
+/**
+ * @brief The DKIMManagerKeyDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
+class MESSAGEVIEWER_EXPORT DKIMManagerKeyDialog : public QDialog
 {
     Q_OBJECT
 public:
@@ -35,7 +39,7 @@ private:
     void readConfig();
     void writeConfig();
     void loadKeys();
-    void saveKeys();
+    void slotAccept();
     DKIMManagerKeyWidget *mManagerWidget = nullptr;
 };
 }
